jactorch.optim.quickaccess
==========================

.. automodule:: jactorch.optim.quickaccess

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      get_optimizer
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: get_optimizer


